# List of all daemons (watchquagga first, zebra last!)
%define daemon_list watchquagga bgpd isisd ospf6d ospfd ripd ripngd zebra
# List of all service entries (ordered!)
%define service_list zebrasrv zebra ripd ripng ospfd bgpd ospf6d ospfapi isisd


Summary:          The Quagga Routing Suite
Name:             quagga
Version:          0.99.18
Release:          1%{?dist}%{?pext}
License:          GPL
Group:            System Environment/Daemons
Source0:          http://www.%{name}.net/download/%{name}-%{version}.tar.gz
Patch0:           %{name}-0.99.18-ospfd_opaque_fixes.patch
Patch1:           %{name}-0.99.18-bgpd_ipv6_fixes.patch
Patch2:           %{name}-0.99.18-lib_format_fixes.patch
Patch10:          %{name}-0.99.16-tcp_md5sig.patch
URL:              http://www.%{name}.net/
Buildroot:        %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
Vendor:           The Quagga Team <security@quagga.net>
Provides:         routingdaemon
Requires:         %{name}-libs = %{version}-%{release}
Requires(pre):    /usr/sbin/groupadd /usr/sbin/useradd
Requires(post):   /sbin/chkconfig /sbin/install-info
Requires(preun):  /sbin/chkconfig /sbin/install-info /sbin/service
Requires(postun): /sbin/service
BuildRequires:    libcap-devel ncurses-devel net-snmp-devel
BuildRequires:    openssl-devel pam-devel readline-devel
Obsoletes:        bird gated mrt zebra

%description
Quagga is a free routing software suite, providing implementations of OSPFv2,
OSPFv3, RIP v1/2, RIPng and BGP-4 for Unix platforms, particularly FreeBSD,
Linux, Solaris and NetBSD. Quagga is a fork of GNU Zebra which was developed
by Kunihiro Ishiguro. It takes a multi-server and multi-thread approach to
resolve the current complexity of the Internet. Quagga is intended to be used
as a Route Server and a Route Reflector.


%package          devel
Summary:          Development tools for Quagga
Group:            Development/Libraries
Requires:         %{name}-libs = %{version}-%{release}
Requires:         net-snmp-devel openssl-devel
Obsoletes:        lib%{name}-devel < %{version}-%{release}

%description      devel
The %{name}-devel package contains the static libraries and header files
for developing OSPF-API and Quagga applications.


%package          libs
Summary:          The Quagga core libraries
Group:            System Environment/Libraries
Obsoletes:        lib%{name} < %{version}-%{release}

%description      libs
The %{name}-libs package contains the Quagga core and support libraries.


%prep
%setup -q

# Upstream patches 
%patch0 -p1
%patch1 -p1
%patch2 -p1

# Local patches
%patch10 -p1


%build
export CFLAGS="${RPM_OPT_FLAGS} -fno-strict-aliasing -Wno-unused -fPIC"

%configure \
	--sysconfdir=%{_sysconfdir}/%{name}           \
	--localstatedir=%{_localstatedir}/run/%{name} \
	--enable-shared                               \
	--enable-static                               \
	--enable-vtysh                                \
	--enable-isisd                                \
	--enable-snmp                                 \
	--enable-opaque-lsa                           \
	--enable-ospf-te                              \
	--enable-multipath=64                         \
	--enable-user=%{name}                         \
	--enable-group=%{name}                        \
	--enable-vty-group=%{name}vty                 \
	--enable-irdp                                 \
	--enable-isis-topology                        \
	--enable-gcc-rdynamic                         \
	--with-libpam                                 \
	ac_cv_have_decl_TCP_MD5SIG=yes

%{__make} %{?_smp_mflags}


%install
[ -n "${RPM_BUILD_ROOT}" -a "${RPM_BUILD_ROOT}" != "/" ] && %{__rm} -rf ${RPM_BUILD_ROOT}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_initrddir}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_sysconfdir}/{logrotate.d,pam.d,sysconfig}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_prefix}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_datadir}/%{name}/contrib
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_localstatedir}/{log,run}/%{name}

%{__make} \
	DESTDIR=${RPM_BUILD_ROOT} \
	install

for DAEMON in %{daemon_list}; do
  %{__install} -m 0755 redhat/${DAEMON}.init  ${RPM_BUILD_ROOT}%{_initrddir}/${DAEMON}
done

%{__install} -m 0644 redhat/%{name}.logrotate ${RPM_BUILD_ROOT}%{_sysconfdir}/logrotate.d/%{name}
%{__install} -m 0644 redhat/%{name}.pam.stack ${RPM_BUILD_ROOT}%{_sysconfdir}/pam.d/%{name}
%{__install} -m 0644 redhat/%{name}.sysconfig ${RPM_BUILD_ROOT}%{_sysconfdir}/sysconfig/%{name}

%{__install} -m 0644 tools/*                  ${RPM_BUILD_ROOT}%{_datadir}/%{name}/contrib

touch                ${RPM_BUILD_ROOT}%{_sysconfdir}/%{name}/{vtysh,zebra}.conf

%{__mv}      -f      ${RPM_BUILD_ROOT}%{_sbindir}/ospfclient ${RPM_BUILD_ROOT}%{_bindir}

%{__rm}      -f      ${RPM_BUILD_ROOT}%{_libdir}/lib*.so.?
%{__rm}      -f      ${RPM_BUILD_ROOT}%{_infodir}/dir


%pre
if ! getent group  %{name}    >/dev/null 2>&1; then
  /usr/sbin/groupadd -r -g 92 %{name}
fi
if ! getent group  %{name}vty >/dev/null 2>&1; then
  /usr/sbin/groupadd -r       %{name}vty
fi
if ! getent passwd %{name}    >/dev/null 2>&1; then
  /usr/sbin/useradd  -r -u 92 -g %{name} \
	-d %{_sysconfdir}/%{name}        \
	-c "Quagga Service User"         \
	-s /sbin/nologin %{name}
fi
exit 0			# Always pass


%post
# Create entries in /etc/services
PORTNR="2600"
for SERVICE in %{service_list}; do
  if ! getent services ${SERVICE} >/dev/null 2>&1; then
    echo -e "${SERVICE}\t\t${PORTNR}/tcp\t\t\t# Quagga" >>%{_sysconfdir}/services
  fi
  let PORTNR=${PORTNR}+1
done

# Create minimal config
if [ ! -e %{_sysconfdir}/%{name}/zebra.conf ]; then
  echo "hostname `hostname`"   >%{_sysconfdir}/%{name}/zebra.conf
  %{__chown} %{name}:%{name}    %{_sysconfdir}/%{name}/zebra.conf
  %{__chmod} 0640               %{_sysconfdir}/%{name}/zebra.conf
fi
if [ ! -e %{_sysconfdir}/%{name}/vtysh.conf ]; then
  touch                         %{_sysconfdir}/%{name}/vtysh.conf
  %{__chown} %{name}:%{name}vty %{_sysconfdir}/%{name}/vtysh.conf
  %{__chmod} 0640               %{_sysconfdir}/%{name}/vtysh.conf
fi

if [ $1 -eq 1 ]; then	# Install
  for DAEMON in %{daemon_list}; do
    /sbin/chkconfig --add ${DAEMON}
  done

  /sbin/install-info %{_infodir}/%{name}.info %{_infodir}/dir
fi

%post libs -p /sbin/ldconfig


%preun
if [ $1 -eq 0 ]; then	# Remove
  for DAEMON in %{daemon_list}; do
    [ -f %{_localstatedir}/lock/subsys/${DAEMON} ] && \
	/sbin/service ${DAEMON} stop >/dev/null 2>&1
    /sbin/chkconfig --del ${DAEMON}
  done

  /sbin/install-info --delete %{_infodir}/%{name}.info %{_infodir}/dir
fi


%postun
if [ $1 -ge 1 ]; then	# Upgrade
  # Restart services
  for DAEMON in %{daemon_list}; do
    if [ -f %{_localstatedir}/lock/subsys/${DAEMON} ]; then
      eval RUNNING_${DAEMON}="yes"
      daemon_reverse="${DAEMON} ${daemon_reverse}"
      /sbin/service ${DAEMON} stop >/dev/null 2>&1
    else
      eval RUNNING_${DAEMON}="no"
    fi
  done

  if [ "${RUNNING_zebra}" = "yes" ]; then
    for DAEMON in ${daemon_reverse}; do
      eval RESTART=\$RUNNING_${DAEMON}

      if [ "${RESTART}" = "yes" ]; then
	/sbin/service ${DAEMON} start >/dev/null 2>&1 || :
      fi
    done
  fi
fi

%postun libs -p /sbin/ldconfig


%clean
[ -n "${RPM_BUILD_ROOT}" -a "${RPM_BUILD_ROOT}" != "/" ] && %{__rm} -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog INSTALL* NEWS README REPORTING*
%doc SERVICES TODO
%doc --parents doc/{BGP*,draft*,fig*,mpls}
%{_initrddir}/bgpd
%{_initrddir}/isisd
%{_initrddir}/ospfd
%{_initrddir}/ospf6d
%{_initrddir}/ripd
%{_initrddir}/ripngd
%{_initrddir}/watchquagga
%{_initrddir}/zebra
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%config(noreplace) %{_sysconfdir}/pam.d/%{name}
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%attr(751,%{name},%{name})    %dir   %{_sysconfdir}/%{name}
%attr(640,%{name},%{name}vty) %ghost %{_sysconfdir}/%{name}/vtysh.conf
%attr(640,%{name},%{name})    %ghost %{_sysconfdir}/%{name}/zebra.conf
%{_sysconfdir}/%{name}/*.sample*
%{_bindir}/ospfclient
%{_bindir}/vtysh
%{_sbindir}/bgpd
%{_sbindir}/isisd
%{_sbindir}/ospfd
%{_sbindir}/ospf6d
%{_sbindir}/ripd
%{_sbindir}/ripngd
%{_sbindir}/watchquagga
%{_sbindir}/zebra
%{_datadir}/%{name}
%{_infodir}/%{name}.info*
%{_mandir}/man1/*.1*
%{_mandir}/man8/*.8*
%attr(750,%{name},%{name}) %dir %{_localstatedir}/log/%{name}
%attr(751,%{name},%{name}) %dir %{_localstatedir}/run/%{name}

%files devel
%defattr(-,root,root)
%{_includedir}/%{name}
%{_libdir}/libospf.*a
%{_libdir}/libospf.so
%{_libdir}/libospfapiclient.*a
%{_libdir}/libospfapiclient.so
%{_libdir}/libzebra.*a
%{_libdir}/libzebra.so

%files libs
%defattr(-,root,root)
%doc COPYING.LIB
%{_libdir}/libospf.so.*
%{_libdir}/libospfapiclient.so.*
%{_libdir}/libzebra.so.*


%changelog
* Fri Apr 08 2011 Peter Pramberger <peterpramb@member.fsf.org> - 0.99.18-1
- New version (0.99.18)

* Sun Sep 26 2010 Peter Pramberger <peterpramb@member.fsf.org> - 0.99.17-1
- New version (0.99.17)

* Mon Apr 19 2010 Peter Pramberger <peterpramb@member.fsf.org> - 0.99.16-2
- Enabled TCP_MD5SIG support (requires appropriate kernel)

* Thu Mar 18 2010 Peter Pramberger <peterpramb@member.fsf.org> - 0.99.16-1
- New version (0.99.16)

* Sat Sep 05 2009 Peter Pramberger <peterpramb@member.fsf.org> - 0.99.15-1
- New version (0.99.15)

* Fri Jul 31 2009 Peter Pramberger <peterpramb@member.fsf.org> - 0.99.14-1
- New version (0.99.14)

* Tue Jul 14 2009 Peter Pramberger <peterpramb@member.fsf.org> - 0.99.13-1
- New version (0.99.13)

* Sun May 17 2009 Peter Pramberger <peterpramb@member.fsf.org> - 0.99.12-1
- New version (0.99.12)

* Wed Feb 18 2009 Peter Pramberger <peterpramb@member.fsf.org> - 0.99.11-1
- New version (0.99.11)

* Thu Oct 11 2007 peter.pramberger@member.fsf.org 0.99.9-6
- new version (0.99.9)

* Tue Aug 07 2007 peter.pramberger@member.fsf.org 0.99.8-5
- new version (0.99.8)

* Wed May 09 2007 peter.pramberger@member.fsf.org 0.99.7-5
- new version (0.99.7)

* Tue Feb 27 2007 peter.pramberger@member.fsf.org 0.99.6-5
- some spec file cleanups (x86_64 support)

* Thu Dec 14 2006 peter.pramberger@member.fsf.org 0.99.6-4
- new version (0.99.6)

* Wed Nov 22 2006 peter.pramberger@member.fsf.org 0.99.5.20061122-4
- new version (0.99.5-20061122)

* Thu Nov 02 2006 peter.pramberger@member.fsf.org 0.99.5.20061102-3
- new version (0.99.5-20061102)

* Wed Sep 20 2006 peter.pramberger@member.fsf.org
- created
